@@ -3,8 +3,8 @@
 #include "matrix.h"
 
 
-void comptestfunc(times,Ntimes,px,cu,vcu,vcudif,antsim,test,testOBS,Ut,simUt,W4t,weighted,antpers,gamma,line)
-double *times,*cu,*vcu,*vcudif,*test,*testOBS,*Ut,*simUt,*gamma;
+void comptestfunc(times,Ntimes,px,cu,vcu,vcudif,antsim,test,testOBS,Ut,simUt,W4t,weighted,antpers,gamma,line,timepow)
+double *times,*cu,*vcu,*vcudif,*test,*testOBS,*Ut,*simUt,*gamma,*timepow;
 int *px,*Ntimes,*antsim,*weighted,*antpers,*line;
 matrix **W4t;
 {
@@ -27,7 +27,8 @@ matrix **W4t;
 
   GetRNGstate();  /* to use R random normals */
 
-  mtime=times[(*Ntimes-1)]; stime=times[0];
+  stime=times[0];
+  mtime=times[(*Ntimes-1)]-stime; 
   tau=times[(*Ntimes-1)]-times[0]; Ut[0]=times[0]; 
   if (*weighted==0) {
     if (*line==0) for (i=0;i<*px;i++) cumweight[i]=tau;
@@ -35,26 +36,24 @@ matrix **W4t;
 
   /* computation of constant effects */ 
   for (i=0;i<*px;i++) {
-    if (*line==0) {
+    if (fabs(timepow[i])<0.01) { // timepow ca 0
       for (s=0;s<*Ntimes;s++)
-	{ time=times[s];dtime=times[s]-times[s-1];
+      {  // time=times[s];dtime=times[s]-times[s-1];
+	 if (vcu[(i+1)*(*Ntimes)+s]>0) {
+	 cumweight[i]=cumweight[i]+(1/vcu[(i+1)*(*Ntimes)+s]);
+	 gamma[i]=gamma[i]+cu[(i+1)*(*Ntimes)+s]/vcu[(i+1)*(*Ntimes)+s];
 
-	  if (*weighted>=0) {
-	    cumweight[i]=cumweight[i]+(1/vcu[(i+1)*(*Ntimes)+s]);
-	    gamma[i]=gamma[i]+cu[(i+1)*(*Ntimes)+s]/vcu[(i+1)*(*Ntimes)+s];
-
-	    for (c=0;c<*antpers;c++) VE(gammai[c],i)=
-	      VE(gammai[c],i)+ME(W4t[c],s,i)/vcu[(i+1)*(*Ntimes)+s]; 
-	  }; 
-	} 
+	 for (c=0;c<*antpers;c++) VE(gammai[c],i)=
+	     VE(gammai[c],i)+ME(W4t[c],s,i)/vcu[(i+1)*(*Ntimes)+s]; 
+	 }
+      } 
       gamma[i]=gamma[i]/cumweight[i]; 
       VE(gammav,i)=gamma[i]; 
       for (c=0;c<*antpers;c++) VE(gammai[c],i)=VE(gammai[c],i)/cumweight[i]; 
     } else  { 
-      gamma[i]=cu[(i+1)*(*Ntimes)+(*Ntimes-1)]/mtime; 
+      gamma[i]=cu[(i+1)*(*Ntimes)+(*Ntimes-1)]/pow(mtime,timepow[i]);; 
       VE(gammav,i)=gamma[i]; 
-      for (c=0;c<*antpers;c++) VE(gammai[c],i)=
-	ME(W4t[c],*Ntimes-1,i)/mtime; 
+      for (c=0;c<*antpers;c++) VE(gammai[c],i)=ME(W4t[c],*Ntimes-1,i)/pow(mtime,timepow[i]);; 
     }
   } /*  i=1..px */
 
@@ -78,7 +77,8 @@ matrix **W4t;
   /* Computation of observed teststatistics */ 
   for (s=1;s<*Ntimes;s++)
     {
-      time=times[s];dtime=times[s]-times[s-1];
+ if (vcu[i*(*Ntimes)+s]>0) {
+      time=times[s]-times[0];dtime=times[s]-times[s-1];
    
       for (i=1;i<=*px;i++) {
 	xij=fabs(cu[i*(*Ntimes)+s])/sqrt(vcu[i*(*Ntimes)+s]);
@@ -86,10 +86,11 @@ matrix **W4t;
 	if (xij>testOBS[i-1]) testOBS[i-1]=xij; } 
 
       for (i=1;i<=*px;i++) VE(xi,i-1)=cu[i*(*Ntimes)+s];
-      if (*line==1) scl_vec_mult(time,gammav,gammavt); 
+//      if (*line==1) scl_vec_mult(time,gammav,gammavt); 
+      for (i=0;i<*px;i++) VE(gammavt,i)=VE(gammav,i)*pow(time,timepow[i]);; 
       vec_subtr(xi,gammavt,difX); vec_star(difX,difX,ssrow); 
 
-      Ut[s]=time; 
+      Ut[s]=times[s]; 
 
       for (i=0;i<*px;i++) { 
         if (*weighted>=2) vardif=vcudif[(i+1)*(*Ntimes)+s];  else vardif=1; 
@@ -105,6 +106,7 @@ matrix **W4t;
         if ((s>*weighted) && (s<*Ntimes-*weighted))  
 	  testOBS[c]=testOBS[c]+VE(ssrow,i)*dtime; }
     } 
+    }
   /*  for (i=0;i<3*(*px);i++) printf(" %lf \n",testOBS[i]);  */
 
   /* simulation of testprocesses and teststatistics */ 
@@ -115,12 +117,14 @@ matrix **W4t;
       random=norm_rand();
       scl_mat_mult(random,W4t[i],tmpM1);mat_add(tmpM1,Delta,Delta); 
       scl_vec_mult(random,gammai[i],xi); vec_add(xi,tmpv1,tmpv1);}
-    scl_vec_mult(1,tmpv1,tmpv1t); 
+      scl_vec_mult(1,tmpv1,tmpv1t); 
 
     for (s=1;s<*Ntimes;s++) { 
+    if (vcu[i*(*Ntimes)+s]>0) {
       time=times[s]-times[0]; dtime=times[s]-times[s-1]; 
       extract_row(Delta,s,rowX); 
-      if (*line==1) scl_vec_mult(times[s],tmpv1,tmpv1t); 
+//      if (*line==1) scl_vec_mult(times[s],tmpv1,tmpv1t); 
+      for (i=0;i<*px;i++) VE(tmpv1t,i)=VE(tmpv1,i)*pow(time,timepow[i]);; 
       vec_subtr(rowX,tmpv1t,difX); vec_star(difX,difX,ssrow); 
 
       for (i=0;i<*px;i++) { 
@@ -140,7 +144,7 @@ matrix **W4t;
         if ((s>*weighted) && (s<*Ntimes-*weighted))  
 	  test[c*(*antsim)+k]=test[c*(*antsim)+k]+VE(ssrow,i)*dtime/vardif; 
       }
-    }  /* s=1..Ntimes */ 
+    } }  /* s=1..Ntimes */ 
   }  /* k=1..antsim */ 
 
   PutRNGstate();   /* to use R random normals */
